---
slug: /overview-of-cursors
---

# Overview

PL stored programs support cursors, and their syntax is the same as that of embedded SQL.

A cursor declaration must appear before the handler declaration and after the variable and condition declarations. A cursor has the following attributes:

* Insensitivity: The server may or may not copy its result table.

* Read-only: It cannot be updated.

* Non-scrollable: It can only traverse in one direction and cannot skip rows.